# Generated by Django 2.2.4 on 2020-06-08 13:52

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('writing', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='article',
            name='category',
            field=models.ForeignKey(blank=True, default=None, null=True, on_delete=django.db.models.deletion.PROTECT, to='writing.Category', verbose_name='category'),
        ),
        migrations.AlterField(
            model_name='article',
            name='excerpt',
            field=models.TextField(help_text='preview', verbose_name='excerpt'),
        ),
        migrations.AlterField(
            model_name='article',
            name='seen',
            field=models.PositiveSmallIntegerField(db_index=True, default=0, verbose_name='seen'),
        ),
    ]
