{% load martortags %}
<h1>{{ article.title }}</h1>
<span>{{ article.author }}</span>
<span>{{ article.created }}</span>

<article>
    <blockquote>{{ article.excerpt }}</blockquote>
    {{ article.content|safe_markdown }}
</article>

{# TODO: comments #}