# Generated by Django 2.2.4 on 2020-06-08 13:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('writing', '0002_auto_20200608_1552'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='article',
            options={'default_permissions': ('list', 'view', 'add', 'change', 'delete'), 'ordering': ['title'], 'verbose_name': 'article', 'verbose_name_plural': 'articles'},
        ),
    ]
